==> italc_1.0.2.orig.tar.gz: italc-1.0.2/ica/win32/src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by WinVNC.rc
//
#define IDI_WINVNC                      102
#define IDR_TRAYMENU                    104
#define IDD_QUERY_SETTINGS              106
#define IDD_PROPERTIES_PARENT           107
#define IDR_VNCVIEWER_JAR               116
#define IDR_RECFRAME_CLASS              117
#define IDR_SESSIONREC_CLASS            118
#define IDR_AUTHPANEL_CLASS             119
#define IDR_RELOGINPANEL_CLASS          120
#define IDR_SOCKFACTORY_CLASS           121
#define IDR_CLIPBOARDFRAME_CLASS        122
#define IDR_OPTIONSFRAME_CLASS          125
#define IDR_RFBPROTO_CLASS              126
#define IDR_VNCCANVAS_CLASS             127
#define IDR_VNCVIEWER_CLASS             128
#define IDR_BUTTONPANEL_CLASS           129
#define IDD_ABOUT                       131
#define IDB_VNCLOGO                     132
#define IDR_DESCIPHER_CLASS             133
#define IDI_FLASH                       134
#define IDD_OUTGOING_CONN               135
#define IDD_ACCEPT_CONN                 136
#define IDI_DISABLED                    138
#define IDD_LIVESHAREPROP               138
#define IDR_LSHTRAYMENU                 139
#define IDD_LIVESHAREADVPROP            139
#define IDB_BITMAP1                     139
#define IDI_LIVESHARE                   140
#define IDB_BITMAP2                     140
#define IDC_CURSOR1                     141
#define IDB_BITMAP3                     142
#define IDI_LIVESHARE_CON               144
#define IDI_LIVESHARE_NOCON             145
#define IDD_ACCEPT_REVERSE              146
#define IDD_SHARED_DESKTOP_AREA         147
#define IDD_INCOMING                    148
#define IDD_UPDATE_HANDLING             150
#define IDD_ADMINISTRATION              152
#define IDR_VNCCANVAS2_CLASS            153
#define IDR_CAPINFO_CLASS               154
#define IDR_CAPSCONTAINER_CLASS         155
#define IDC_HOSTNAME_EDIT               1001
#define IDC_PRIMARY_DISPLAY_ONLY        1002
#define IDC_STATIC_DRVINFO              1003
#define IDC_CONNECT_SOCK                1004
#define IDC_BLANK_SCREEN                1005
#define IDC_VNCLOGO                     1006
#define IDC_PASSWORD_LABEL              1007
#define IDC_DISPLAYNO                   1008
#define IDC_PASSWORD                    1009
#define IDC_UPDATE_BORDER               1010
#define IDC_POLL_FULLSCREEN             1011
#define IDC_CONSOLE_ONLY                1012
#define IDC_POLL_FOREGROUND             1013
#define IDC_POLL_UNDER_CURSOR           1014
#define IDC_ONEVENT_ONLY                1015
#define IDC_REMOTE_DISABLE              1016
#define IDC_PORTHTTP                    1017
#define IDC_PORTRFB                     1018
#define IDC_PASSWORD_VIEWONLY_LABEL     1019
#define IDC_PASSWORD_VIEWONLY           1020
#define IDC_URL_PARAMS                  1021
#define IDC_STATIC_DRVSTATUS            1022
#define IDC_STATIC_TRSH                 1023
#define IDC_DISABLE_INPUTS              1024
#define IDC_APPLY                       1025
#define IDC_PORTNO_AUTO                 1026
#define IDC_DISABLE_LOCAL_INPUTS        1027
#define IDC_HOSTNAME_STATIC             1028
#define IDC_STATIC_WNDPOLLING           1029
#define IDACCEPT                        1030
#define IDREJECT                        1031
#define IDC_STATIC_TEXT1                1032
#define IDC_ACCEPT_IP                   1033
#define IDC_STATIC_TEXT                 1034
#define IDC_ACCEPT_TIMEOUT              1035
#define IDACCEPT_NOPASS                 1036
#define IDADVANCED                      1037
#define IDC_STATIC_TEXT2                1038
#define IDQUERY                         1039
#define IDQUERYTIMEOUT                  1042
#define IDREQUIREAUTH                   1043
#define IDQUERYALLOWNOPASS              1044
#define IDONLYLOOPBACK                  1045
#define IDLOGLOTS                       1047
#define IDALLOWLOOPBACK                 1048
#define IDLOG                           1050
#define IDPRIORITY0                     1052
#define IDPRIORITY2                     1053
#define IDPRIORITY1                     1054
#define IDENABLEHTTPD                   1055
#define IDC_SHARINGAREA_BORDER          1056
#define IDC_LIVESHARE_BORDER            1057
#define IDC_NAME_APPLI                  1058
#define IDC_LIVESHARE                   1059
#define IDC_BMPCURSOR                   1060
#define IDC_WINDOW                      1061
#define IDC_SCREEN                      1062
#define IDC_FULLSCREEN                  1063
#define IDC_DISABLE_TIME                1064
#define IDC_TIMEOUT_LABEL               1065
#define IDC_SECONDS_LABEL               1066
#define IDC_STATIC_INCOMING             1067
#define IDC_STATIC_INPUT                1068
#define IDC_STATIC_DISCONNECT           1069
#define IDC_STATIC_POLLING              1070
#define IDC_SPECDISPLAY                 1071
#define IDC_SPECPORT                    1072
#define IDC_POLLING_CYCLE               1073
#define IDC_ACTION_REFUSE               1074
#define IDC_ACTION_ACCEPT               1075
#define IDC_REMOVE_WALLPAPER            1076
#define IDC_LOCKSETTING_NOTHING         1077
#define IDC_LOCKSETTING_LOCK            1078
#define IDC_LOCKSETTING_LOGOFF          1079
#define IDC_DONT_SET_HOOKS              1080
#define IDC_STATIC_PCYCLE               1081
#define IDC_STATIC_MS                   1082
#define IDC_ENABLE_FILE_TRANSFERS       1083
#define IDC_AND_LABEL                   1084
#define IDC_MAIN_LABEL                  1085
#define IDC_HTTP_LABEL                  1086
#define IDC_TAB                         1087
#define IDC_STATIC_AND                  1088
#define IDC_STATIC_SECONDS              1089
#define IDC_STATIC_TIMEOUT              1090
#define IDC_STATIC_ACTION               1091
#define IDC_STATIC_TEMPORARY            1092
#define IDC_STATIC_CONN_PRIOR           1093
#define IDC_STATIC_ADMINISTR            1094
#define IDC_STATIC_DISPLAY_PORT         1095
#define IDC_POLCYCLMS_LABEL             1096
#define IDC_LIVESHARE_LABEL             1097
#define IDC_DONT_USE_DRIVER             1098
#define IDC_DRIVER_DIRECT_ACCESS        1099
#define IDC_STATIC_DRVOPT               1100
#define IDC_STATIC_QUERY                1101
#define IDC_STATIC_LOGGING              1102
#define ID_PROPERTIES                   40001
#define ID_CLOSE                        40002
#define ID_KILLCLIENTS                  40003
#define ID_ABOUT                        40004
#define ID_OUTGOING_CONN                40005
#define ID_DEFAULT_PROPERTIES           40006
#define ID_DISABLE_CONN                 40007

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        156
#define _APS_NEXT_COMMAND_VALUE         40008
#define _APS_NEXT_CONTROL_VALUE         1103
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> italc_1.0.9~rc3.orig.tar.gz: italc-1.0.9~rc3/ica/win32/src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by WinVNC.rc
//
#define IDI_WINVNC                      102
#define IDR_TRAYMENU                    104
#define IDD_QUERY_SETTINGS              106
#define IDD_PROPERTIES_PARENT           107
#define IDR_INSTREAM_CLASS              108
#define IDR_MEMINSTREAM_CLASS           109
#define IDR_ZLIBINSTREAM_CLASS          110
#define IDR_VNCVIEWER_JAR               116
#define IDR_RECFRAME_CLASS              117
#define IDR_SESSIONREC_CLASS            118
#define IDR_AUTHPANEL_CLASS             119
#define IDR_RELOGINPANEL_CLASS          120
#define IDR_SOCKFACTORY_CLASS           121
#define IDR_CLIPBOARDFRAME_CLASS        122
#define IDR_OPTIONSFRAME_CLASS          125
#define IDR_RFBPROTO_CLASS              126
#define IDR_VNCCANVAS_CLASS             127
#define IDR_VNCVIEWER_CLASS             128
#define IDR_BUTTONPANEL_CLASS           129
#define IDD_ABOUT                       131
#define IDB_VNCLOGO                     132
#define IDR_DESCIPHER_CLASS             133
#define IDI_FLASH                       134
#define IDD_OUTGOING_CONN               135
#define IDD_ACCEPT_CONN                 136
#define IDI_DISABLED                    138
#define IDD_LIVESHAREPROP               138
#define IDR_LSHTRAYMENU                 139
#define IDD_LIVESHAREADVPROP            139
#define IDB_BITMAP1                     139
#define IDI_LIVESHARE                   140
#define IDB_BITMAP2                     140
#define IDC_CURSOR1                     141
#define IDB_BITMAP3                     142
#define IDI_LIVESHARE_CON               144
#define IDI_LIVESHARE_NOCON             145
#define IDD_ACCEPT_REVERSE              146
#define IDD_SHARED_DESKTOP_AREA         147
#define IDD_INCOMING                    148
#define IDD_UPDATE_HANDLING             150
#define IDD_ADMINISTRATION              152
#define IDR_VNCCANVAS2_CLASS            153
#define IDR_CAPINFO_CLASS               154
#define IDR_CAPSCONTAINER_CLASS         155
#define IDC_HOSTNAME_EDIT               1001
#define IDC_PRIMARY_DISPLAY_ONLY        1002
#define IDC_STATIC_DRVINFO              1003
#define IDC_CONNECT_SOCK                1004
#define IDC_BLANK_SCREEN                1005
#define IDC_VNCLOGO                     1006
#define IDC_PASSWORD_LABEL              1007
#define IDC_DISPLAYNO                   1008
#define IDC_PASSWORD                    1009
#define IDC_UPDATE_BORDER               1010
#define IDC_POLL_FULLSCREEN             1011
#define IDC_CONSOLE_ONLY                1012
#define IDC_POLL_FOREGROUND             1013
#define IDC_POLL_UNDER_CURSOR           1014
#define IDC_ONEVENT_ONLY                1015
#define IDC_REMOTE_DISABLE              1016
#define IDC_PORTHTTP                    1017
#define IDC_PORTRFB                     1018
#define IDC_PASSWORD_VIEWONLY_LABEL     1019
#define IDC_PASSWORD_VIEWONLY           1020
#define IDC_URL_PARAMS                  1021
#define IDC_STATIC_DRVSTATUS            1022
#define IDC_STATIC_TRSH                 1023
#define IDC_DISABLE_INPUTS              1024
#define IDC_APPLY                       1025
#define IDC_PORTNO_AUTO                 1026
#define IDC_DISABLE_LOCAL_INPUTS        1027
#define IDC_HOSTNAME_STATIC             1028
#define IDC_STATIC_WNDPOLLING           1029
#define IDACCEPT                        1030
#define IDREJECT                        1031
#define IDC_STATIC_TEXT1                1032
#define IDC_ACCEPT_IP                   1033
#define IDC_STATIC_TEXT                 1034
#define IDC_ACCEPT_TIMEOUT              1035
#define IDACCEPT_NOPASS                 1036
#define IDADVANCED                      1037
#define IDC_STATIC_TEXT2                1038
#define IDQUERY                         1039
#define IDQUERYTIMEOUT                  1042
#define IDREQUIREAUTH                   1043
#define IDQUERYALLOWNOPASS              1044
#define IDONLYLOOPBACK                  1045
#define IDLOGLOTS                       1047
#define IDALLOWLOOPBACK                 1048
#define IDLOG                           1050
#define IDPRIORITY0                     1052
#define IDPRIORITY2                     1053
#define IDPRIORITY1                     1054
#define IDENABLEHTTPD                   1055
#define IDC_SHARINGAREA_BORDER          1056
#define IDC_LIVESHARE_BORDER            1057
#define IDC_NAME_APPLI                  1058
#define IDC_LIVESHARE                   1059
#define IDC_BMPCURSOR                   1060
#define IDC_WINDOW                      1061
#define IDC_SCREEN                      1062
#define IDC_FULLSCREEN                  1063
#define IDC_DISABLE_TIME                1064
#define IDC_TIMEOUT_LABEL               1065
#define IDC_SECONDS_LABEL               1066
#define IDC_STATIC_INCOMING             1067
#define IDC_STATIC_INPUT                1068
#define IDC_STATIC_DISCONNECT           1069
#define IDC_STATIC_POLLING              1070
#define IDC_SPECDISPLAY                 1071
#define IDC_SPECPORT                    1072
#define IDC_POLLING_CYCLE               1073
#define IDC_ACTION_REFUSE               1074
#define IDC_ACTION_ACCEPT               1075
#define IDC_REMOVE_WALLPAPER            1076
#define IDC_LOCKSETTING_NOTHING         1077
#define IDC_LOCKSETTING_LOCK            1078
#define IDC_LOCKSETTING_LOGOFF          1079
#define IDC_DONT_SET_HOOKS              1080
#define IDC_STATIC_PCYCLE               1081
#define IDC_STATIC_MS                   1082
#define IDC_ENABLE_FILE_TRANSFERS       1083
#define IDC_AND_LABEL                   1084
#define IDC_MAIN_LABEL                  1085
#define IDC_HTTP_LABEL                  1086
#define IDC_TAB                         1087
#define IDC_STATIC_AND                  1088
#define IDC_STATIC_SECONDS              1089
#define IDC_STATIC_TIMEOUT              1090
#define IDC_STATIC_ACTION               1091
#define IDC_STATIC_TEMPORARY            1092
#define IDC_STATIC_CONN_PRIOR           1093
#define IDC_STATIC_ADMINISTR            1094
#define IDC_STATIC_DISPLAY_PORT         1095
#define IDC_POLCYCLMS_LABEL             1096
#define IDC_LIVESHARE_LABEL             1097
#define IDC_DONT_USE_DRIVER             1098
#define IDC_DRIVER_DIRECT_ACCESS        1099
#define IDC_STATIC_DRVOPT               1100
#define IDC_STATIC_QUERY                1101
#define IDC_STATIC_LOGGING              1102
#define IDC_BUILDTIME                   1103
#define ID_PROPERTIES                   40001
#define ID_CLOSE                        40002
#define ID_KILLCLIENTS                  40003
#define ID_ABOUT                        40004
#define ID_OUTGOING_CONN                40005
#define ID_DEFAULT_PROPERTIES           40006
#define ID_DISABLE_CONN                 40007

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        156
#define _APS_NEXT_COMMAND_VALUE         40008
#define _APS_NEXT_CONTROL_VALUE         1104
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
